#ifndef TK_CALIBRATION_H
#define TK_CALIBRATION_H
/*
 * Attiny calibration header.
 * This allows using a single set of hardcoded values across multiple projects.
 *
 * Copyright (C) 2015 Selene Scriven
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


/********************** Voltage ADC calibration **************************/
//  First values are from Dale's wight+1 driver measurements - these
// value also work well for the BLF Q8 SRK drivers
//
// See battcheck/readings.txt for reference values.

//#define ADC_100p   ADC_42  // the ADC value for 100% full (resting)
//#define ADC_75p    ADC_40  // the ADC value for 75% full (resting)
//#define ADC_50p    ADC_38  // the ADC value for 50% full (resting)
//#define ADC_25p    ADC_35  // the ADC value for 25% full (resting)
//#define ADC_0p     ADC_30  // the ADC value for 0% full (resting)

#ifdef USING_2200K   // GT-buck
// The ADC values we expect for specific voltages: 2.2v to 4.4v. This is
//  for using R1=1000K, R2=47K, and direct connection from Batt+
//  to R1, no diode in-between
#define ADC_44     192
#define ADC_43     188
#define ADC_42     184	// 100%
#define ADC_41     180
#define ADC_40     173	//  75%
#define ADC_39     171
#define ADC_38     167	//  50%
#define ADC_37     163
#define ADC_36     159
#define ADC_35     155	//  25%
#define ADC_34     150
#define ADC_33     146
#define ADC_32     142
#define ADC_31     138
#define ADC_30     134	//   0%
#define ADC_29     130
#define ADC_28     125
#define ADC_27     121
#define ADC_26     117
#define ADC_25     113
#define ADC_24     109
#define ADC_23     104
#define ADC_22     100
#endif

#ifdef USING_1000K   // GT-buck
// The ADC values we expect for specific voltages: 2.2v to 4.4v. This is
//  for using R1=1000K, R2=47K, and direct connection from Batt+
//  to R1, no diode in-between
#define ADC_44     184
#define ADC_43     180
#define ADC_42     176	// 100%
#define ADC_41     171
#define ADC_40     167	//  75%
#define ADC_39     163
#define ADC_38     159	//  50%
#define ADC_37     155
#define ADC_36     150
#define ADC_35     146	//  25%
#define ADC_34     142
#define ADC_33     138
#define ADC_32     134
#define ADC_31     130
#define ADC_30     125	//   0%
#define ADC_29     121
#define ADC_28     117
#define ADC_27     113
#define ADC_26     109
#define ADC_25     104
#define ADC_24     100
#define ADC_23     96
#define ADC_22     92
#endif

#ifdef USING_1000K_01   // GT-buck
// The ADC values we expect for specific voltages: 2.2v to 4.4v. This is
//  for using R1=1000K, R2=47K, and direct connection from Batt+
//  to R1, no diode in-between
#define ADC_44     188
#define ADC_43     184
#define ADC_42     180	// 100%
#define ADC_41     176
#define ADC_40     171	//  75%
#define ADC_39     167
#define ADC_38     163	//  50%
#define ADC_37     159
#define ADC_36     155
#define ADC_35     150	//  25%
#define ADC_34     146
#define ADC_33     142
#define ADC_32     138
#define ADC_31     134
#define ADC_30     130	//   0%
#define ADC_29     125
#define ADC_28     121
#define ADC_27     117
#define ADC_26     113
#define ADC_25     109
#define ADC_24     104
#define ADC_23     100
#define ADC_22     96
#endif

#ifdef USING_1000K_02   // GT-buck
// The ADC values we expect for specific voltages: 2.2v to 4.4v. This is
//  for using R1=1000K, R2=47K, and direct connection from Batt+
//  to R1, no diode in-between
#define ADC_44     192
#define ADC_43     188
#define ADC_42     184	// 100%
#define ADC_41     180
#define ADC_40     173	//  75%
#define ADC_39     171
#define ADC_38     167	//  50%
#define ADC_37     163
#define ADC_36     159
#define ADC_35     155	//  25%
#define ADC_34     150
#define ADC_33     146
#define ADC_32     142
#define ADC_31     138
#define ADC_30     134	//   0%
#define ADC_29     130
#define ADC_28     125
#define ADC_27     121
#define ADC_26     117
#define ADC_25     113
#define ADC_24     109
#define ADC_23     104
#define ADC_22     100
#endif

#ifdef USING_1000K_m01   // GT-buck
// The ADC values we expect for specific voltages: 2.2v to 4.4v. This is
//  for using R1=1000K, R2=47K, and direct connection from Batt+
//  to R1, no diode in-between
#define ADC_44     180
#define ADC_43     176
#define ADC_42     171	// 100%
#define ADC_41     167
#define ADC_40     163	//  75%
#define ADC_39     159
#define ADC_38     155	//  50%
#define ADC_37     150
#define ADC_36     146
#define ADC_35     142	//  25%
#define ADC_34     138
#define ADC_33     134
#define ADC_32     130
#define ADC_31     125
#define ADC_30     121	//   0%
#define ADC_29     117
#define ADC_28     113
#define ADC_27     109
#define ADC_26     104
#define ADC_25     100
#define ADC_24     96
#define ADC_23     92
#define ADC_22     88
#endif

#ifdef USING_1000K_m005   // GT-buck
// The ADC values we expect for specific voltages: 2.2v to 4.4v. This is
//  for using R1=1000K, R2=47K, and direct connection from Batt+
//  to R1, no diode in-between
#define ADC_44     182
#define ADC_43     178
#define ADC_42     174	// 100%
#define ADC_41     170
#define ADC_40     166	//  75%
#define ADC_39     162
#define ADC_38     156	//  50%
#define ADC_37     152
#define ADC_36     148
#define ADC_35     144	//  25%
#define ADC_34     140
#define ADC_33     136
#define ADC_32     132
#define ADC_31     127
#define ADC_30     123	//   0%
#define ADC_29     119
#define ADC_28     115
#define ADC_27     111
#define ADC_26     106
#define ADC_25     102
#define ADC_24     98
#define ADC_23     94
#define ADC_22     90
#endif

#ifdef USING_680K   // GT-buck
// The ADC values we expect for specific voltages: 2.2v to 4.4v. This is
//  for using R1=1000K, R2=47K, and direct connection from Batt+
//  to R1, no diode in-between
#define ADC_44     209
#define ADC_43     204
#define ADC_42     199	// 100%
#define ADC_41     194
#define ADC_40     189	//  75%
#define ADC_39     184
#define ADC_38     179	//  50%
#define ADC_37     174
#define ADC_36     169
#define ADC_35     165	//  25%
#define ADC_34     161
#define ADC_33     156
#define ADC_32     151
#define ADC_31     146
#define ADC_30     142	//   0%
#define ADC_29     138
#define ADC_28     134
#define ADC_27     130
#define ADC_26     125
#define ADC_25     121
#define ADC_24     117
#define ADC_23     113
#define ADC_22     109
#endif

#ifdef USING_680K_m01   // GT-buck
// The ADC values we expect for specific voltages: 2.2v to 4.4v. This is
//  for using R1=1000K, R2=47K, and direct connection from Batt+
//  to R1, no diode in-between
#define ADC_44     213
#define ADC_43     209
#define ADC_42     204	// 100%
#define ADC_41     199
#define ADC_40     194	//  75%
#define ADC_39     189
#define ADC_38     184	//  50%
#define ADC_37     179
#define ADC_36     174
#define ADC_35     169	//  25%
#define ADC_34     165
#define ADC_33     161
#define ADC_32     156
#define ADC_31     151
#define ADC_30     146	//   0%
#define ADC_29     142
#define ADC_28     138
#define ADC_27     134
#define ADC_26     130
#define ADC_25     125
#define ADC_24     121
#define ADC_23     117
#define ADC_22     113
#endif

#ifdef USING_680K_m02  // GT-buck
// The ADC values we expect for specific voltages: 2.2v to 4.4v. This is
//  for using R1=1000K, R2=47K, and direct connection from Batt+
//  to R1, no diode in-between
#define ADC_44     218
#define ADC_43     213
#define ADC_42     209	// 100%
#define ADC_41     204
#define ADC_40     199	//  75%
#define ADC_39     194
#define ADC_38     189	//  50%
#define ADC_37     184
#define ADC_36     179
#define ADC_35     174	//  25%
#define ADC_34     169
#define ADC_33     165
#define ADC_32     161
#define ADC_31     156
#define ADC_30     151	//   0%
#define ADC_29     146
#define ADC_28     142
#define ADC_27     138
#define ADC_26     134
#define ADC_25     130
#define ADC_24     125
#define ADC_23     121
#define ADC_22     117
#endif

#ifdef USING_680K_m03  // GT-buck
// The ADC values we expect for specific voltages: 2.2v to 4.4v. This is
//  for using R1=1000K, R2=47K, and direct connection from Batt+
//  to R1, no diode in-between
#define ADC_44     222
#define ADC_43     218
#define ADC_42     213	// 100%
#define ADC_41     209
#define ADC_40     204	//  75%
#define ADC_39     199
#define ADC_38     194	//  50%
#define ADC_37     189
#define ADC_36     184
#define ADC_35     179	//  25%
#define ADC_34     174
#define ADC_33     169
#define ADC_32     165
#define ADC_31     161
#define ADC_30     156	//   0%
#define ADC_29     151
#define ADC_28     146
#define ADC_27     142
#define ADC_26     138
#define ADC_25     134
#define ADC_24     130
#define ADC_23     125
#define ADC_22     121
#endif

#ifdef USING_680K_01   // GT-buck
// The ADC values we expect for specific voltages: 2.2v to 4.4v. This is
//  for using R1=1000K, R2=47K, and direct connection from Batt+
//  to R1, no diode in-between
#define ADC_44     204
#define ADC_43     199
#define ADC_42     194	// 100%
#define ADC_41     189
#define ADC_40     184	//  75%
#define ADC_39     179
#define ADC_38     174	//  50%
#define ADC_37     169
#define ADC_36     165
#define ADC_35     161	//  25%
#define ADC_34     156
#define ADC_33     151
#define ADC_32     146
#define ADC_31     142
#define ADC_30     138	//   0%
#define ADC_29     134
#define ADC_28     130
#define ADC_27     125
#define ADC_26     121
#define ADC_25     117
#define ADC_24     113
#define ADC_23     109
#define ADC_22     105
#endif

#ifdef USING_680K_02   // GT-buck
// The ADC values we expect for specific voltages: 2.2v to 4.4v. This is
//  for using R1=1000K, R2=47K, and direct connection from Batt+
//  to R1, no diode in-between
#define ADC_44     199
#define ADC_43     194
#define ADC_42     189	// 100%
#define ADC_41     184
#define ADC_40     179	//  75%
#define ADC_39     174
#define ADC_38     169	//  50%
#define ADC_37     165
#define ADC_36     161
#define ADC_35     156	//  25%
#define ADC_34     151
#define ADC_33     146
#define ADC_32     142
#define ADC_31     138
#define ADC_30     134	//   0%
#define ADC_29     130
#define ADC_28     125
#define ADC_27     121
#define ADC_26     117
#define ADC_25     113
#define ADC_24     109
#define ADC_23     105
#define ADC_22     101
#endif

#ifdef USING_360K
// The ADC values we expect for specific voltages: 4.4V to 8.8V (2.2v to 4.4v). This is
//  for using R1=360K/36K, R2=47K/4.7K, and direct connection from Batt+
//  to R1, no diode in-between, with an LDO and a 2S battery configuration.
#define ADC_44     236
#define ADC_43     230
#define ADC_42     225	// 100%
#define ADC_41     220
#define ADC_40     214	//  75%
#define ADC_39     209
#define ADC_38     203	//  50%
#define ADC_37     198
#define ADC_36     193
#define ADC_35     187	//  25%
#define ADC_34     182
#define ADC_33     177
#define ADC_32     171
#define ADC_31     166
#define ADC_30     161	//   0%
#define ADC_29     155
#define ADC_28     150
#define ADC_27     145
#define ADC_26     139
#define ADC_25     134
#define ADC_24     129
#define ADC_23     123
#define ADC_22     118
#endif

#ifdef USING_360K_005
// The ADC values we expect for specific voltages: 4.4V to 8.8V (2.2v to 4.4v). This is
//  for using R1=360K/36K, R2=47K/4.7K, and direct connection from Batt+
//  to R1, no diode in-between, with an LDO and a 2S battery configuration.
#define ADC_44     239
#define ADC_43     236
#define ADC_42     228	// 100%
#define ADC_41     223
#define ADC_40     217	//  75%
#define ADC_39     212
#define ADC_38     206	//  50%
#define ADC_37     201
#define ADC_36     196
#define ADC_35     190	//  25%
#define ADC_34     185
#define ADC_33     180
#define ADC_32     174
#define ADC_31     169
#define ADC_30     164	//   0%
#define ADC_29     158
#define ADC_28     153
#define ADC_27     148
#define ADC_26     141
#define ADC_25     137
#define ADC_24     132
#define ADC_23     126
#define ADC_22     121
#endif

#ifdef USING_360K_01
// The ADC values we expect for specific voltages: 4.4V to 8.8V (2.2v to 4.4v). This is
//  for using R1=360K/36K, R2=47K/4.7K, and direct connection from Batt+
//  to R1, no diode in-between, with an LDO and a 2S battery configuration.
#define ADC_44     242
#define ADC_43     236
#define ADC_42     230	// 100%
#define ADC_41     225
#define ADC_40     220	//  75%
#define ADC_39     214
#define ADC_38     209	//  50%
#define ADC_37     203
#define ADC_36     198
#define ADC_35     193	//  25%
#define ADC_34     187
#define ADC_33     182
#define ADC_32     177
#define ADC_31     171
#define ADC_30     166	//   0%
#define ADC_29     161
#define ADC_28     155
#define ADC_27     150
#define ADC_26     145
#define ADC_25     139
#define ADC_24     134
#define ADC_23     129
#define ADC_22     123
#endif

#ifdef USING_360K_m01
// The ADC values we expect for specific voltages: 4.4V to 8.8V (2.2v to 4.4v). This is
//  for using R1=360K/36K, R2=47K/4.7K, and direct connection from Batt+
//  to R1, no diode in-between, with an LDO and a 2S battery configuration.
#define ADC_44     230
#define ADC_43     225
#define ADC_42     220	// 100%
#define ADC_41     214
#define ADC_40     209	//  75%
#define ADC_39     203
#define ADC_38     198	//  50%
#define ADC_37     193
#define ADC_36     187
#define ADC_35     182	//  25%
#define ADC_34     177
#define ADC_33     171
#define ADC_32     166
#define ADC_31     161
#define ADC_30     155	//   0%
#define ADC_29     150
#define ADC_28     145
#define ADC_27     139
#define ADC_26     134
#define ADC_25     129
#define ADC_24     123
#define ADC_23     118
#define ADC_22     113
#endif

#ifdef USING_360K_m005
// The ADC values we expect for specific voltages: 4.4V to 8.8V (2.2v to 4.4v). This is
//  for using R1=360K/36K, R2=47K/4.7K, and direct connection from Batt+
//  to R1, no diode in-between, with an LDO and a 2S battery configuration.
#define ADC_44     233
#define ADC_43     228
#define ADC_42     223	// 100%
#define ADC_41     217
#define ADC_40     212	//  75%
#define ADC_39     206
#define ADC_38     201	//  50%
#define ADC_37     196
#define ADC_36     190
#define ADC_35     185	//  25%
#define ADC_34     180
#define ADC_33     174
#define ADC_32     169
#define ADC_31     164
#define ADC_30     158	//   0%
#define ADC_29     153
#define ADC_28     148
#define ADC_27     142
#define ADC_26     137
#define ADC_25     132
#define ADC_24     126
#define ADC_23     121
#define ADC_22     116
#endif

#ifdef USING_220K
// The ADC values we expect for specific voltages: 2.0v to 4.4v. This is
//  for using R1=220K/22K, R2=47K/4.7K, and direct connection from Batt+
//  to R1, no diode in-between
#define ADC_44     184	// 205
#define ADC_43     180	// 201
#define ADC_42     175	// 196  100%
#define ADC_41     171	// 191
#define ADC_40     167	// 187   75%
#define ADC_39     163	// 182
#define ADC_38     159	// 177   50%
#define ADC_37     154	// 172
#define ADC_36     150	// 168
#define ADC_35     146	// 163   25%
#define ADC_34     141	// 158
#define ADC_33     136	// 153
#define ADC_32     132	// 149
#define ADC_31     128	// 144
#define ADC_30     124	// 139   0%
#define ADC_29     120	// 134
#define ADC_28     117	// 130
#define ADC_27     112	// 125  ---
#define ADC_26     108	// 120
#define ADC_25     104	// 116
#define ADC_24     100	// 111
#define ADC_23      96	// 106
#define ADC_22      92	// 101
#define ADC_21      88	// 97
#define ADC_20      84	// 92
#endif

#endif  // TK_CALIBRATION_H
